@@ -1,3 +1,4 @@
+import sys
 import time
 from timeit import default_timer
 
@@ -6,13 +7,42 @@ from botocore.config import Config
 from loguru import logger
 from prometheus_client import start_http_server
 
-from prometheus_ecs_discoverer import conf, discovery, fetching, marshalling
-from prometheus_ecs_discoverer import settings as s
-from prometheus_ecs_discoverer import telemetry
+from prometheus_ecs_discoverer import (discovery, fetching, marshalling, s,
+                                       telemetry)
 
 # Copyright 2020 Tim Schwenke. Licensed under the Apache License 2.0
 
 
+INTERVAL_BREACHED = telemetry.counter(
+    "execution_breaches_total",
+    "Number of times the discovery round took longer than the configured interval.",
+)
+INTERVAL_BREACHED.inc(0)
+
+
+def configure_logging():
+    logger.remove()
+
+    if s.LOG_JSON:
+        fmt = "{message}"
+        logger.add(sys.stderr, format=fmt, serialize=True, level=s.LOG_LEVEL)
+    else:
+        # <green>{time:HH:mm:ss}</green> <level>{level}</level> <cyan>{name}:{function}:{line}</cyan> {message} <dim>{extra}</dim>
+        fmt = "<green>{time:HH:mm:ss}</green> <level>{level}</level> <cyan>{function}</cyan> {message} <dim>{extra}</dim>"
+        logger.add(sys.stderr, colorize=True, format=fmt, level=s.LOG_LEVEL)
+
+    if s.BOTO3_DEBUG:
+        import boto3
+
+        boto3.set_stream_logger(name="botocore")
+
+
+def expose_info() -> None:
+    telemetry.info(
+        {"interval_seconds": str(s.INTERVAL),}
+    )
+
+
 def get_interval_histogram(interval: int):
     steps = 10
     step_size = round(interval / steps, 0)
@@ -24,12 +54,16 @@ def get_interval_histogram(interval: int):
     )
 
 
+# ==============================================================================
+
+
 def main():
     interval = s.INTERVAL
     output_dir = s.OUTPUT_DIRECTORY
     should_throttle = s.WARMUP_THROTTLE
 
-    conf.configure_logging()
+    configure_logging()
+    expose_info()
 
     logger.info("Welcome to PromED, the Prometheus ECS Discoverer.")
     logger.bind(settings=s.as_dict()).info("Here is the used configuration.")
@@ -82,6 +116,12 @@ def main():
         logger.bind(duration=duration).info("Finished discovery round.")
         DURATION.observe(duration)
 
+        if duration > interval:
+            logger.bind(duration=duration).error(
+                "Discovery round took longer than the configured interval. Please investigate."
+            )
+            INTERVAL_BREACHED.inc()
+
         time_left = max(interval - duration, 0)
         time.sleep(time_left)
 
